==> knt_ui-1.0.0.tar.gz: lib/src/widget/knt_app_wrapper.dart <==
import 'package:device_preview/device_preview.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

import '../../knt_ui.dart';

typedef PreviewDeviceAppBuilder = Widget Function(BuildContext, Widget?);
typedef KntAppBuilder = Widget Function(
    BuildContext context, Locale?, PreviewDeviceAppBuilder?);

class KntAppWrapper extends StatelessWidget {
  final KntAppBuilder appBuilder;
  final List<Locale> supportedLocales;
  final String? localizedPath;
  final bool debugShowPreviewDevice;

  const KntAppWrapper({
    Key? key,
    required this.appBuilder,
    required this.supportedLocales,
    this.localizedPath,
    this.debugShowPreviewDevice = true,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final fallbackLocale = supportedLocales.isNotEmpty
        ? supportedLocales.first
        : Locale(DefinedSetting.defaultLanguageCode);
    return EasyLocalization(
      supportedLocales: supportedLocales,
      path: localizedPath ?? DefinedSetting.localeAssetPath,
      fallbackLocale: fallbackLocale,
      child: ScreenUtilInit(
        designSize: Size(
          DefinedUI.defaultDesignWidth,
          DefinedUI.defaultDesignHeight,
        ),
        builder: () => GestureDetector(
          onTap: () {
            FocusManager.instance.primaryFocus?.unfocus();
          },
          child: DevicePreview(
            enabled: debugShowPreviewDevice,
            availableLocales: supportedLocales,
            builder: (context) => appBuilder.call(
              context,
              DevicePreview.locale(context),
              DevicePreview.appBuilder,
            ),
          ),
        ),
      ),
    );
  }
}

==> knt_ui-1.1.2.tar.gz: lib/src/widget/knt_app_wrapper.dart <==
import 'package:flutter/material.dart';

import '../../knt_ui.dart';

typedef PreviewDeviceAppBuilder = Widget Function(BuildContext, Widget?);
typedef KntAppBuilder = Widget Function(
    BuildContext context, Locale?, PreviewDeviceAppBuilder?);

class KntAppWrapper extends StatelessWidget {
  final KntAppBuilder appBuilder;
  final List<Locale> supportedLocales;
  final String? localizedPath;
  final bool debugShowPreviewDevice;

  const KntAppWrapper({
    Key? key,
    required this.appBuilder,
    required this.supportedLocales,
    this.localizedPath,
    this.debugShowPreviewDevice = true,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final fallbackLocale = supportedLocales.isNotEmpty
        ? supportedLocales.first
        : Locale(DefinedSetting.defaultLanguageCode);
    return EasyLocalization(
      supportedLocales: supportedLocales,
      path: localizedPath ?? DefinedSetting.localeAssetPath,
      fallbackLocale: fallbackLocale,
      child: ScreenUtilInit(
        designSize: Size(
          DefinedUI.defaultDesignWidth,
          DefinedUI.defaultDesignHeight,
        ),
        builder: () => GestureDetector(
          onTap: () {
            FocusManager.instance.primaryFocus?.unfocus();
          },
          child: DevicePreview(
            enabled: debugShowPreviewDevice,
            availableLocales: supportedLocales,
            builder: (context) => MediaQuery(
              data: MediaQuery.of(context).copyWith(
                textScaleFactor: DefinedUI.defaultFontScaleFactor,
              ),
              child: appBuilder.call(
                context,
                DevicePreview.locale(context),
                DevicePreview.appBuilder,
              ),
            ),
          ),
        ),
      ),
    );
  }
}
